"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const glob = require("glob");
const parseConfigFile_1 = require("./parseConfigFile");
const loadPlugin_1 = require("./plugins/loadPlugin");
const util_1 = require("util");
async function tsGen(deps, args) {
    const { cwd } = args;
    const { fs, logger, prettier } = deps;
    const genConfig = await parseConfigFile_1.parseConfigFile(deps, args);
    for (const config of genConfig.plugins) {
        const ctx = { cwd, config };
        const plugin = loadPlugin_1.loadPlugin(deps, ctx);
        await plugin.init();
        const filePaths = glob.sync(config.files, { ignore: "node_modules/**", absolute: true, cwd });
        const fileDescs = filePaths.map(path => ({
            path,
            contents: fs.readFileSync(path, "utf8"),
        }));
        for (const fd of fileDescs) {
            logger.info(`Processing ${fd.path} with ${config.generator} plugin`);
            const output = await plugin.transformFile(fd);
            const outputFds = util_1.isArray(output) ? output : [output];
            outputFds.forEach(fd => fs.writeFileSync(fd.path, prettier.format(fd.contents, genConfig.prettier), "utf8"));
        }
    }
}
exports.tsGen = tsGen;
